==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodSecurityPolicySubjectReviewSpecBuilder extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder>{
  public PodSecurityPolicySubjectReviewSpecBuilder() {
    this(false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PodSecurityPolicySubjectReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicySubjectReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroups(instance.getGroups()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance) {
    this(instance,false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroups(instance.getGroups()); 
    this.withTemplate(instance.getTemplate()); 
    this.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec build() {
    PodSecurityPolicySubjectReviewSpec buildable = new PodSecurityPolicySubjectReviewSpec(fluent.getGroups(),fluent.getTemplate(),fluent.getUser());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicySubjectReviewSpecBuilder that = (PodSecurityPolicySubjectReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodSecurityPolicySubjectReviewSpecBuilder extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder>{
  public PodSecurityPolicySubjectReviewSpecBuilder() {
    this(false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PodSecurityPolicySubjectReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicySubjectReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroups(instance.getGroups()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withUser(instance.getUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance) {
    this(instance,false);
  }
  public PodSecurityPolicySubjectReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroups(instance.getGroups()); 
    this.withTemplate(instance.getTemplate()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec build() {
    PodSecurityPolicySubjectReviewSpec buildable = new PodSecurityPolicySubjectReviewSpec(fluent.getGroups(),fluent.getTemplate(),fluent.getUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicySubjectReviewSpecBuilder that = (PodSecurityPolicySubjectReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
